pub trait IcebergCatalogClient: Send + Sync {
// Required methods
fn list_tables<'life0, 'life1, 'async_trait>(
&'life0 self,
namespace: &'life1 str,
) -> Pin<Box<dyn Future<Output = CatalogResult<Vec<String>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn load_table<'life0, 'life1, 'async_trait>(
&'life0 self,
table: &'life1 IcebergTableId,
) -> Pin<Box<dyn Future<Output = CatalogResult<LoadedIcebergTable>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
// Provided method
fn load_table_metadata<'life0, 'life1, 'async_trait>(
&'life0 self,
table: &'life1 IcebergTableId,
) -> Pin<Box<dyn Future<Output = CatalogResult<Value>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait { ... }
}Expand description
Read-only operations implemented by the Iceberg REST catalog client.
Table mutations are intentionally absent until Krishiv has a typed commit request model with Iceberg requirements and updates.
Required Methods
fn list_tables<'life0, 'life1, 'async_trait>(
&'life0 self,
namespace: &'life1 str,
) -> Pin<Box<dyn Future<Output = CatalogResult<Vec<String>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn load_table<'life0, 'life1, 'async_trait>(
&'life0 self,
table: &'life1 IcebergTableId,
) -> Pin<Box<dyn Future<Output = CatalogResult<LoadedIcebergTable>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Provided Methods
fn load_table_metadata<'life0, 'life1, 'async_trait>(
&'life0 self,
table: &'life1 IcebergTableId,
) -> Pin<Box<dyn Future<Output = CatalogResult<Value>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".