pub struct FunctionArgDef {
pub name: String,
pub data_type: DataType,
}Expand description
A typed function argument extracted from the function signature.
Fields
name: Stringdata_type: DataTypeTrait Implementations
Sourceimpl Clone for FunctionArgDef
impl Clone for FunctionArgDef
Sourcefn clone(&self) -> FunctionArgDef
fn clone(&self) -> FunctionArgDef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionArgDef
impl Debug for FunctionArgDef
impl Eq for FunctionArgDef
Sourceimpl PartialEq for FunctionArgDef
impl PartialEq for FunctionArgDef
Sourcefn eq(&self, other: &FunctionArgDef) -> bool
fn eq(&self, other: &FunctionArgDef) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FunctionArgDef