pub fn dfplan_body_partition_spec(body: &str) -> SqlResult<DfplanTaskSpec>Expand description
Parse the partition spec of a body without decoding the plan payload (cheap coordinator-side inspection).
pub fn dfplan_body_partition_spec(body: &str) -> SqlResult<DfplanTaskSpec>Parse the partition spec of a body without decoding the plan payload (cheap coordinator-side inspection).