pub fn dfplan_task_body_for_spec(
plan_bytes_b64: &str,
spec: &DfplanTaskSpec,
) -> StringExpand description
Assemble a fragment body executing several root partitions (coalescing).
pub fn dfplan_task_body_for_spec(
plan_bytes_b64: &str,
spec: &DfplanTaskSpec,
) -> StringAssemble a fragment body executing several root partitions (coalescing).