pub fn process_pipe_syntax(sql: &str) -> Result<String, PipeSyntaxError>Expand description
Pre-process SQL to convert pipe syntax to standard SQL.
If the SQL does not contain pipe syntax, it is returned unchanged.
pub fn process_pipe_syntax(sql: &str) -> Result<String, PipeSyntaxError>Pre-process SQL to convert pipe syntax to standard SQL.
If the SQL does not contain pipe syntax, it is returned unchanged.