pub struct PipelineRegistry { /* private fields */ }Expand description
SQL-layer registry of declared pipeline sources and sinks (metadata only).
Implementations
Sourceimpl PipelineRegistry
impl PipelineRegistry
pub fn new() -> Self
pub fn register_source( &self, name: impl Into<String>, spec: SourceSpec, ) -> SqlResult<()>
pub fn register_sink( &self, name: impl Into<String>, spec: SinkSpec, ) -> SqlResult<()>
pub fn source(&self, name: &str) -> SqlResult<Option<SourceSpec>>
pub fn sink(&self, name: &str) -> SqlResult<Option<SinkSpec>>
Sourcepub fn view_for_sink(&self, name: &str) -> SqlResult<Option<String>>
pub fn view_for_sink(&self, name: &str) -> SqlResult<Option<String>>
View name backing the given sink, if the sink is registered.
Returns None for unknown sinks.
Sourcepub fn sink_names(&self) -> SqlResult<Vec<String>>
pub fn sink_names(&self) -> SqlResult<Vec<String>>
Names of all declared sinks.
Sourcepub fn sources(&self) -> SqlResult<Vec<(String, SourceSpec)>>
pub fn sources(&self) -> SqlResult<Vec<(String, SourceSpec)>>
All declared source specs (name, spec).
pub fn remove_source(&self, name: &str) -> SqlResult<bool>
pub fn remove_sink(&self, name: &str) -> SqlResult<bool>