pub struct SinkSpec {
pub view: String,
pub connector: Option<ConnectorSpec>,
}Expand description
A declared sink: which view’s output it collects, and optionally where it is
written (a connector). With no connector, the output is returned as a result
set by START PIPELINE.
Fields
view: Stringconnector: Option<ConnectorSpec>Trait Implementations
impl Eq for SinkSpec
impl StructuralPartialEq for SinkSpec