pub trait KrishivDataFrameOps: Send + Sync {
Show 36 methods
// Required methods
fn collect<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<Vec<RecordBatch>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn collect_with_stats<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<(Vec<RecordBatch>, SqlExecutionStats)>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn explain<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<String>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn explain_logical(&self) -> String;
fn krishiv_logical_plan(&self) -> LogicalPlan;
fn query(&self) -> Option<&str>;
fn execute_stream<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<SqlStream>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn schema(&self) -> SchemaRef;
fn select<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn select_exprs<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
expressions: &'life1 [&'life2 Expr],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn aggregate<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
group_exprs: &'life1 [&'life2 Expr],
aggregate_exprs: &'life3 [&'life4 Expr],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait;
fn aggregate_grouping<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
grouping: GroupingMode<'life1>,
aggregate_exprs: &'life2 [&'life3 Expr],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn pivot<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'async_trait>(
&'life0 self,
group_exprs: &'life1 [&'life2 Expr],
pivot_column: &'life3 Expr,
aggregate_expr: &'life4 Expr,
values: &'life5 [(ScalarValue, String)],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait;
fn unpivot<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
name_column: &'life3 str,
value_column: &'life4 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait;
fn filter<'life0, 'life1, 'async_trait>(
&'life0 self,
predicate: &'life1 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn filter_expr<'life0, 'life1, 'async_trait>(
&'life0 self,
predicate: &'life1 Expr,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn limit<'life0, 'async_trait>(
&'life0 self,
n: usize,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn distinct<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn drop_nulls<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn sample<'life0, 'async_trait>(
&'life0 self,
fraction: f64,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn sort<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
descending: &'life3 [bool],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn alias<'life0, 'life1, 'async_trait>(
&'life0 self,
alias: &'life1 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn drop_columns<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn rename_column<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
old: &'life1 str,
new: &'life2 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn with_column<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
name: &'life1 str,
expr: &'life2 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn as_any(&self) -> &dyn Any;
fn describe<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn fill_null<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
column: &'life1 str,
value: &'life2 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn join<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'life6, 'async_trait>(
&'life0 self,
right: &'life1 dyn KrishivDataFrameOps,
how: &'life2 str,
left_on: &'life3 [&'life4 str],
right_on: &'life5 [&'life6 str],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
'life6: 'async_trait;
fn union<'life0, 'life1, 'async_trait>(
&'life0 self,
right: &'life1 dyn KrishivDataFrameOps,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn union_distinct<'life0, 'life1, 'async_trait>(
&'life0 self,
right: &'life1 dyn KrishivDataFrameOps,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn intersect<'life0, 'life1, 'async_trait>(
&'life0 self,
right: &'life1 dyn KrishivDataFrameOps,
distinct: bool,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn except<'life0, 'life1, 'async_trait>(
&'life0 self,
right: &'life1 dyn KrishivDataFrameOps,
distinct: bool,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn register_batches<'life0, 'life1, 'async_trait>(
&'life0 self,
name: &'life1 str,
batches: Vec<RecordBatch>,
) -> Pin<Box<dyn Future<Output = SqlResult<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn deregister_table<'life0, 'life1, 'async_trait>(
&'life0 self,
name: &'life1 str,
) -> Pin<Box<dyn Future<Output = SqlResult<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn create_view<'life0, 'life1, 'async_trait>(
&'life0 self,
name: &'life1 str,
replace: bool,
) -> Pin<Box<dyn Future<Output = SqlResult<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Required Methods
Sourcefn collect<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<Vec<RecordBatch>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn collect<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<Vec<RecordBatch>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Execute and collect all result batches.
Sourcefn collect_with_stats<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<(Vec<RecordBatch>, SqlExecutionStats)>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn collect_with_stats<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<(Vec<RecordBatch>, SqlExecutionStats)>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Execute, collect results, and return lightweight runtime statistics.
Sourcefn explain<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<String>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn explain<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<String>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Explain the physical and logical plan text (does not execute).
Sourcefn explain_logical(&self) -> String
fn explain_logical(&self) -> String
Explain the logical plan text without executing.
Sourcefn krishiv_logical_plan(&self) -> LogicalPlan
fn krishiv_logical_plan(&self) -> LogicalPlan
Build a Krishiv LogicalPlan wrapper for this DataFrame.
Sourcefn execute_stream<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<SqlStream>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn execute_stream<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<SqlStream>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Execute and return a record batch stream.
Sourcefn select<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn select<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Select columns by name.
Sourcefn select_exprs<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
expressions: &'life1 [&'life2 Expr],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn select_exprs<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
expressions: &'life1 [&'life2 Expr],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Select arbitrary SQL expressions.
Sourcefn aggregate<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
group_exprs: &'life1 [&'life2 Expr],
aggregate_exprs: &'life3 [&'life4 Expr],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
fn aggregate<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
group_exprs: &'life1 [&'life2 Expr],
aggregate_exprs: &'life3 [&'life4 Expr],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
Group by expressions and compute aggregate expressions.
Sourcefn aggregate_grouping<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
grouping: GroupingMode<'life1>,
aggregate_exprs: &'life2 [&'life3 Expr],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn aggregate_grouping<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
grouping: GroupingMode<'life1>,
aggregate_exprs: &'life2 [&'life3 Expr],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Aggregate using GROUPING SETS, CUBE, or ROLLUP.
Sourcefn pivot<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'async_trait>(
&'life0 self,
group_exprs: &'life1 [&'life2 Expr],
pivot_column: &'life3 Expr,
aggregate_expr: &'life4 Expr,
values: &'life5 [(ScalarValue, String)],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
fn pivot<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'async_trait>(
&'life0 self,
group_exprs: &'life1 [&'life2 Expr],
pivot_column: &'life3 Expr,
aggregate_expr: &'life4 Expr,
values: &'life5 [(ScalarValue, String)],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
Pivot known values into aggregate columns.
Sourcefn unpivot<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
name_column: &'life3 str,
value_column: &'life4 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
fn unpivot<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
name_column: &'life3 str,
value_column: &'life4 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
Unpivot columns into name/value rows while preserving other columns.
Sourcefn filter<'life0, 'life1, 'async_trait>(
&'life0 self,
predicate: &'life1 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn filter<'life0, 'life1, 'async_trait>(
&'life0 self,
predicate: &'life1 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Filter rows by a SQL predicate expression.
Sourcefn filter_expr<'life0, 'life1, 'async_trait>(
&'life0 self,
predicate: &'life1 Expr,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn filter_expr<'life0, 'life1, 'async_trait>(
&'life0 self,
predicate: &'life1 Expr,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Filter rows using the engine-owned typed expression AST.
Sourcefn limit<'life0, 'async_trait>(
&'life0 self,
n: usize,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn limit<'life0, 'async_trait>(
&'life0 self,
n: usize,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Limit the number of rows.
Sourcefn distinct<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn distinct<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Remove duplicate rows.
Sourcefn drop_nulls<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn drop_nulls<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Drop rows with nulls in selected columns; an empty list checks all columns.
Sourcefn sample<'life0, 'async_trait>(
&'life0 self,
fraction: f64,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn sample<'life0, 'async_trait>(
&'life0 self,
fraction: f64,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Bernoulli-sample rows.
Sourcefn sort<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
descending: &'life3 [bool],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn sort<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
descending: &'life3 [bool],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Sort by columns with optional descending flags.
Sourcefn alias<'life0, 'life1, 'async_trait>(
&'life0 self,
alias: &'life1 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn alias<'life0, 'life1, 'async_trait>(
&'life0 self,
alias: &'life1 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Assign an alias (table name) to this DataFrame.
Sourcefn drop_columns<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn drop_columns<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
columns: &'life1 [&'life2 str],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Drop columns by name.
Sourcefn rename_column<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
old: &'life1 str,
new: &'life2 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn rename_column<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
old: &'life1 str,
new: &'life2 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Rename a column from old to new.
Sourcefn with_column<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
name: &'life1 str,
expr: &'life2 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn with_column<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
name: &'life1 str,
expr: &'life2 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Add or replace a column with a computed expression.
Sourcefn describe<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn describe<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Compute summary statistics (delegates to DataFusion’s describe).
Sourcefn fill_null<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
column: &'life1 str,
value: &'life2 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn fill_null<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
column: &'life1 str,
value: &'life2 str,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Fill null values in column with the literal SQL value.
Sourcefn join<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'life6, 'async_trait>(
&'life0 self,
right: &'life1 dyn KrishivDataFrameOps,
how: &'life2 str,
left_on: &'life3 [&'life4 str],
right_on: &'life5 [&'life6 str],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
'life6: 'async_trait,
fn join<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'life6, 'async_trait>(
&'life0 self,
right: &'life1 dyn KrishivDataFrameOps,
how: &'life2 str,
left_on: &'life3 [&'life4 str],
right_on: &'life5 [&'life6 str],
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
'life6: 'async_trait,
Join with another DataFrame using a join type and equi-join keys.
Sourcefn union<'life0, 'life1, 'async_trait>(
&'life0 self,
right: &'life1 dyn KrishivDataFrameOps,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn union<'life0, 'life1, 'async_trait>(
&'life0 self,
right: &'life1 dyn KrishivDataFrameOps,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Union this DataFrame with another (UNION ALL semantics).
fn union_distinct<'life0, 'life1, 'async_trait>(
&'life0 self,
right: &'life1 dyn KrishivDataFrameOps,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn intersect<'life0, 'life1, 'async_trait>(
&'life0 self,
right: &'life1 dyn KrishivDataFrameOps,
distinct: bool,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn except<'life0, 'life1, 'async_trait>(
&'life0 self,
right: &'life1 dyn KrishivDataFrameOps,
distinct: bool,
) -> Pin<Box<dyn Future<Output = SqlResult<Box<dyn KrishivDataFrameOps>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Sourcefn register_batches<'life0, 'life1, 'async_trait>(
&'life0 self,
name: &'life1 str,
batches: Vec<RecordBatch>,
) -> Pin<Box<dyn Future<Output = SqlResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn register_batches<'life0, 'life1, 'async_trait>(
&'life0 self,
name: &'life1 str,
batches: Vec<RecordBatch>,
) -> Pin<Box<dyn Future<Output = SqlResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Register a list of record batches as a named in-memory table in the
same session context that backs this DataFrame. Used by cache().
Sourcefn deregister_table<'life0, 'life1, 'async_trait>(
&'life0 self,
name: &'life1 str,
) -> Pin<Box<dyn Future<Output = SqlResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn deregister_table<'life0, 'life1, 'async_trait>(
&'life0 self,
name: &'life1 str,
) -> Pin<Box<dyn Future<Output = SqlResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Deregister a named table from the session context. Used by unpersist().
Sourcefn create_view<'life0, 'life1, 'async_trait>(
&'life0 self,
name: &'life1 str,
replace: bool,
) -> Pin<Box<dyn Future<Output = SqlResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn create_view<'life0, 'life1, 'async_trait>(
&'life0 self,
name: &'life1 str,
replace: bool,
) -> Pin<Box<dyn Future<Output = SqlResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Create (or replace) a SQL view named name backed by this DataFrame’s
query. Used by create_or_replace_temp_view().
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".