pub fn semi_join_pushdown_enabled() -> boolExpand description
Whether semi-join pushdown through an inner join is enabled (default: yes).
See SEMI_JOIN_PUSHDOWN_ENV for why the default is on, and for the one
revision where it was not.
pub fn semi_join_pushdown_enabled() -> boolWhether semi-join pushdown through an inner join is enabled (default: yes).
See SEMI_JOIN_PUSHDOWN_ENV for why the default is on, and for the one
revision where it was not.